diff -ur nginx-1.1.13/src/http/modules/ngx_http_xslt_filter_module.c nginx-1.1.13-new/src/http/modules/ngx_http_xslt_filter_module.c
--- nginx-1.1.13/src/http/modules/ngx_http_xslt_filter_module.c	2010-07-12 14:52:01.000000000 +0200
+++ nginx-1.1.13-new/src/http/modules/ngx_http_xslt_filter_module.c	2012-02-26 15:55:25.000000000 +0100
@@ -10,6 +10,7 @@
 
 #include <libxml/parser.h>
 #include <libxml/tree.h>
+#include <libxslt/variables.h>
 #include <libxslt/xslt.h>
 #include <libxslt/xsltInternals.h>
 #include <libxslt/transform.h>
@@ -44,10 +45,18 @@
 
 
 typedef struct {
+    u_char			*name;
+    ngx_http_complex_value_t	 value;
+    ngx_uint_t			 no_eval; /* unsigned  no_eval:1; */
+} ngx_http_xslt_param_t;
+
+
+typedef struct {
     xmlDtdPtr            dtd;
     ngx_array_t          sheets;       /* ngx_http_xslt_sheet_t */
     ngx_hash_t           types;
     ngx_array_t         *types_keys;
+    ngx_array_t         *params;       /* ngx_http_xslt_param_t */
 } ngx_http_xslt_filter_loc_conf_t;
 
 
@@ -75,7 +84,9 @@
 static ngx_buf_t *ngx_http_xslt_apply_stylesheet(ngx_http_request_t *r,
     ngx_http_xslt_filter_ctx_t *ctx);
 static ngx_int_t ngx_http_xslt_params(ngx_http_request_t *r,
-    ngx_http_xslt_filter_ctx_t *ctx, ngx_array_t *params);
+    ngx_http_xslt_filter_ctx_t *ctx,
+    xsltTransformContextPtr xctxt,
+    ngx_array_t *params);
 static u_char *ngx_http_xslt_content_type(xsltStylesheetPtr s);
 static u_char *ngx_http_xslt_encoding(xsltStylesheetPtr s);
 static void ngx_http_xslt_cleanup(void *data);
@@ -84,6 +95,8 @@
     void *conf);
 static char *ngx_http_xslt_stylesheet(ngx_conf_t *cf, ngx_command_t *cmd,
     void *conf);
+static char *ngx_http_xslt_stylesheet_param(ngx_conf_t *cf, ngx_command_t *cmd,
+    void *conf);
 static void ngx_http_xslt_cleanup_dtd(void *data);
 static void ngx_http_xslt_cleanup_stylesheet(void *data);
 static void *ngx_http_xslt_filter_create_main_conf(ngx_conf_t *cf);
@@ -116,6 +129,20 @@
       0,
       NULL },
 
+    { ngx_string("xslt_param"),
+      NGX_HTTP_MAIN_CONF|NGX_HTTP_SRV_CONF|NGX_HTTP_LOC_CONF|NGX_CONF_TAKE2,
+      ngx_http_xslt_stylesheet_param,
+      NGX_HTTP_LOC_CONF_OFFSET,
+      0,
+      NULL },
+
+    { ngx_string("xslt_string_param"),
+      NGX_HTTP_MAIN_CONF|NGX_HTTP_SRV_CONF|NGX_HTTP_LOC_CONF|NGX_CONF_TAKE2,
+      ngx_http_xslt_stylesheet_param,
+      NGX_HTTP_LOC_CONF_OFFSET,
+      0,
+      (void *)0x1 },
+
     { ngx_string("xslt_types"),
       NGX_HTTP_MAIN_CONF|NGX_HTTP_SRV_CONF|NGX_HTTP_LOC_CONF|NGX_CONF_1MORE,
       ngx_http_types_slot,
@@ -450,6 +477,7 @@
     ngx_uint_t                        i;
     xmlChar                          *buf;
     xmlDocPtr                         doc, res;
+    xsltTransformContextPtr           xctxt;
     ngx_http_xslt_sheet_t            *sheet;
     ngx_http_xslt_filter_loc_conf_t  *conf;
 
@@ -468,13 +496,23 @@
 
     for (i = 0; i < conf->sheets.nelts; i++) {
 
-        if (ngx_http_xslt_params(r, ctx, &sheet[i].params) != NGX_OK) {
+        xctxt = xsltNewTransformContext(sheet[i].stylesheet, doc);
+        if (xctxt == NULL) {
+            xmlFreeDoc(doc);
+            return NULL;
+        }
+
+        if (ngx_http_xslt_params(r, ctx, xctxt, &sheet[i].params) != NGX_OK) {
+            xsltFreeTransformContext(xctxt);
             xmlFreeDoc(doc);
             return NULL;
         }
 
-        res = xsltApplyStylesheet(sheet[i].stylesheet, doc, ctx->params.elts);
+        res = xsltApplyStylesheetUser(sheet[i].stylesheet, doc,
+                                      ctx->params.elts,
+                                      NULL, NULL, xctxt);
 
+        xsltFreeTransformContext(xctxt);
         xmlFreeDoc(doc);
 
         if (res == NULL) {
@@ -564,13 +602,67 @@
 
 static ngx_int_t
 ngx_http_xslt_params(ngx_http_request_t *r, ngx_http_xslt_filter_ctx_t *ctx,
+    xsltTransformContextPtr xctxt,
     ngx_array_t *params)
 {
-    u_char                    *p, *last, *value, *dst, *src, **s;
-    size_t                     len;
-    ngx_uint_t                 i;
-    ngx_str_t                  string;
-    ngx_http_complex_value_t  *param;
+    u_char                          *p, *last, *value, *dst, *src, **s;
+    size_t                           len;
+    ngx_uint_t                       i;
+    ngx_str_t                        string;
+    ngx_http_complex_value_t        *param;
+    ngx_http_xslt_param_t           *xparam;
+    ngx_http_xslt_filter_loc_conf_t *conf;
+
+
+    conf = ngx_http_get_module_loc_conf(r, ngx_http_xslt_filter_module);
+
+    /* location params */
+
+    if (conf->params) {
+        xparam = conf->params->elts;
+
+        for (i = 0; i < conf->params->nelts; i++) {
+
+            if (ngx_http_complex_value(r, &xparam[i].value, &string)
+                != NGX_OK) {
+                return NGX_ERROR;
+            }
+
+            ngx_log_debug1(NGX_LOG_DEBUG_HTTP, r->connection->log, 0,
+                           "xslt filter param name: \"%s\"", xparam[i].name);
+            ngx_log_debug1(NGX_LOG_DEBUG_HTTP, r->connection->log, 0,
+                           "xslt filter param value: \"%s\"", string.data);
+
+            if (xparam[i].no_eval) {
+                if (xsltQuoteOneUserParam(xctxt, xparam[i].name,
+                                          string.data) != 0) {
+
+                    ngx_log_error(NGX_LOG_ERR, r->connection->log, 0,
+                                  "xslt filter quoting failed \"%s\" = \"%s\"",
+                                  xparam[i].name, string.data);
+
+                    continue;
+                }
+
+            } else {
+                s = ngx_array_push(&ctx->params);
+                if (s == NULL) {
+                    return NGX_ERROR;
+                }
+
+                *s = xparam[i].name;
+
+                s = ngx_array_push(&ctx->params);
+                if (s == NULL) {
+                    return NGX_ERROR;
+                }
+
+                *s = string.data;
+            }
+        }
+    }
+
+    /* per-stylesheet params */
 
     param = params->elts;
 
@@ -865,6 +957,54 @@
 }
 
 
+static char *
+ngx_http_xslt_stylesheet_param(ngx_conf_t *cf, ngx_command_t *cmd,
+    void *conf)
+{
+    ngx_http_xslt_filter_loc_conf_t  *xlcf = conf;
+
+    ngx_http_xslt_param_t            *param;
+    ngx_http_compile_complex_value_t  ccv;
+    ngx_str_t                        *value;
+
+    value = cf->args->elts;
+
+    if (xlcf->params == NULL) {
+        xlcf->params = ngx_array_create(cf->pool, 2,
+                                        sizeof(ngx_http_xslt_param_t));
+        if (xlcf->params == NULL) {
+            return NGX_CONF_ERROR;
+        }
+    }
+
+    param = ngx_array_push(xlcf->params);
+    if (param == NULL) {
+        return NGX_CONF_ERROR;
+    }
+
+    param->name = value[1].data;
+    if (cmd->post == NULL) {
+        param->no_eval = 0;
+
+    } else {
+        param->no_eval = 1;
+    }
+
+    ngx_memzero(&ccv, sizeof(ngx_http_compile_complex_value_t));
+
+    ccv.cf = cf;
+    ccv.value = &value[2];
+    ccv.complex_value = &param->value;
+    ccv.zero = 1;
+
+    if (ngx_http_compile_complex_value(&ccv) != NGX_OK) {
+        return NGX_CONF_ERROR;
+    }
+
+    return NGX_CONF_OK;
+}
+
+
 static void
 ngx_http_xslt_cleanup_dtd(void *data)
 {
@@ -917,6 +1057,8 @@
         return NULL;
     }
 
+    conf->params = NULL;
+
     /*
      * set by ngx_pcalloc():
      *
@@ -944,6 +1086,10 @@
         conf->sheets = prev->sheets;
     }
 
+    if (conf->params == NULL) {
+        conf->params = prev->params;
+    }
+
     if (ngx_http_merge_types(cf, &conf->types_keys, &conf->types,
                              &prev->types_keys, &prev->types,
                              ngx_http_xslt_default_types)